@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -247,6 +247,7 @@ sub gen_inline_pericmd_script {
             map {$_ => _get_module($_)} qw(
                                               Data::Check::Structure
                                               Text::Table::Tiny
+                                              Getopt::Long::Less
                                       )
         },
     };
@@ -549,9 +550,8 @@ _
         $cd->{vars}{'%_pci_args'}++;
         push @l, "# parse cmdline options\n\n";
         push @l, "{\n";
-        push @l, "require Getopt::Long;\n";
+        push @l, "require Getopt::Long::Less;\n";
         push @l, 'my %mentioned_args;', "\n";
-        push @l, qq[Getopt::Long::Configure("bundling", "no_ignore_case");\n];
         {
             push @l, 'my $go_spec = {', "\n";
             for my $go_spec (sort keys %{ $ggl_res->[2] }) {
@@ -611,7 +611,7 @@ _
                 push @l, "    },\n";
             }
             push @l, "};\n";
-            push @l, 'my $res = Getopt::Long::GetOptions(%$go_spec);', "\n";
+            push @l, 'my $res = Getopt::Long::Less::GetOptions(%$go_spec);', "\n";
             push @l, '_pci_err([500, "GetOptions failed"]) unless $res;', "\n";
             push @l, '_pci_debug("args after GetOptions: ", \%_pci_args);', "\n" if $args{with_debug};
             push @l, '$res = _pci_check_args(\%_pci_args);', "\n";
@@ -751,7 +751,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
+This document describes version 0.08 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
 
 =head1 SYNOPSIS
 
@@ -777,23 +777,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                    Rate  run 1 (lite) run --version (lite) run 1 (inline) run --version (inline)   -c (lite) -c (inline)   perl
- run 1 (lite)           13.649+-0.0081/s            --               -61.3%         -79.2%                 -81.9%      -82.5%      -91.6% -97.6%
- run --version (lite)    35.264+-0.055/s 158.36+-0.43%                   --         -46.2%                 -53.2%      -54.8%      -78.4% -93.8%
- run 1 (inline)             65.6+-0.14/s     380.6+-1%         86.04+-0.48%             --                 -12.9%      -16.0%      -59.8% -88.5%
- run --version (inline)   75.281+-0.06/s 451.55+-0.55%        113.48+-0.38%   14.75+-0.25%                     --       -3.6%      -53.8% -86.9%
- -c (lite)                 78.08+-0.17/s   472.1+-1.3%         121.42+-0.6%   19.02+-0.36%            3.72+-0.24%          --      -52.1% -86.4%
- -c (inline)                163.1+-1.6/s     1095+-12%          362.5+-4.7%    148.6+-2.5%            116.6+-2.2% 108.9+-2.1%          -- -71.5%
- perl                       572.7+-3.1/s     4096+-23%         1524.2+-9.3%      773+-5.1%            660.8+-4.2% 633.5+-4.3%   251.2+-4%     --
+                                   Rate  run 1 (lite) run --version (lite) run 1 (inline)   -c (lite) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.602+-0.014/s            --               -59.2%         -79.0%      -81.8%                 -81.8%      -93.7% -97.0%
+ run --version (lite)     33.37+-0.16/s   145.4+-1.2%                   --         -48.5%      -55.3%                 -55.3%      -84.5% -92.5%
+ run 1 (inline)         64.804+-0.095/s 376.44+-0.85%         94.18+-0.95%             --      -13.1%                 -13.2%      -69.9% -85.5%
+ -c (lite)                74.58+-0.37/s   448.3+-2.8%          123.5+-1.5%   15.09+-0.59%          --                  -0.1%      -65.4% -83.3%
+ run --version (inline)   74.68+-0.16/s   449.1+-1.3%          123.8+-1.2%   15.24+-0.31% 0.13+-0.54%                     --      -65.3% -83.3%
+ -c (inline)               215.3+-1.3/s  1482.9+-9.7%          545.1+-4.9%    232.2+-2.1% 188.7+-2.3%            188.3+-1.9%          -- -51.9%
+ perl                        447.7+-3/s     3192+-22%            1242+-11%    590.9+-4.8%   500.3+-5%            499.5+-4.2%   108+-1.9%     --
  
  Average times:
-   perl                  :     1.7461ms
-   -c (inline)           :     6.1312ms
-   -c (lite)             :    12.8074ms
-   run --version (inline):    13.2836ms
-   run 1 (inline)        :    15.2439ms
-   run --version (lite)  :    28.3575ms
-   run 1 (lite)          :    73.2654ms
+   perl                  :     2.2336ms
+   -c (inline)           :     4.6447ms
+   run --version (inline):    13.3905ms
+   -c (lite)             :    13.4084ms
+   run 1 (inline)        :    15.4311ms
+   run --version (lite)  :    29.9670ms
+   run 1 (lite)          :    73.5186ms
 
 =head1 FUNCTIONS
 
